@@ -4,7 +4,7 @@
 
 namespace libcppe {
 namespace {
-static const std::string static_version_string = "0.2.1";
+static const std::string static_version_string = "0.3.1";
 
 static const std::vector<std::string> version_split = [](const std::string& in) {
   std::vector<std::string> parts;
@@ -37,7 +37,9 @@ std::string version::version_string() { return static_version_string; }
 
 std::string __authors__() { return "Maximilian Scheurer"; }
 
-std::string __contributors__() { return "Peter Reinholdt, Michael F. Herbst, Lori A. Burns"; }
+std::string __contributors__() {
+  return "Peter Reinholdt, Michael F. Herbst, Lori A. Burns";
+}
 
 std::string __email__() { return "maximilian.scheurer@iwr.uni-heidelberg.de"; }
 
