@@ -10,6 +10,7 @@ void export_state(py::module&);
 void export_fields(py::module&);
 void export_math(py::module&);
 void export_tensors(py::module&);
+void export_fmm(py::module&);
 
 PYBIND11_MODULE(cppe, cppe) {
   cppe.doc()                    = "Python interface for CPPE";
@@ -26,4 +27,5 @@ PYBIND11_MODULE(cppe, cppe) {
   export_fields(cppe);
   export_math(cppe);
   export_tensors(cppe);
+  export_fmm(cppe);
 }
\ No newline at end of file
