@@ -7,8 +7,9 @@
 
 namespace py = pybind11;
 
+PYBIND11_MAKE_OPAQUE(std::vector<libcppe::Atom>);
+
 void export_molecule(py::module& m) {
-  // libcppe::Atom
   py::class_<libcppe::Atom> atom(m, "Atom", "Atom class");
   atom.def(py::init<int, double, double, double>())
         .def_readwrite("atomic_number", &libcppe::Atom::atomic_number)
@@ -16,8 +17,7 @@ void export_molecule(py::module& m) {
         .def_readwrite("x", &libcppe::Atom::m_x)
         .def_readwrite("y", &libcppe::Atom::m_y)
         .def_readwrite("z", &libcppe::Atom::m_z)
-        .def_property_readonly("position", &libcppe::Atom::get_pos);
+        .def_property_readonly("position", &libcppe::Atom::get_position);
 
-  // libcppe::Molecule
-  py::bind_vector<libcppe::Molecule>(m, "Molecule");
+  py::bind_vector<std::vector<libcppe::Atom>>(m, "Molecule");
 }
\ No newline at end of file
